==> clean-5.x-1.4.tar.gz: clean/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.1.2.3 2008/09/12 15:55:42 psynaptic Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language ?>" lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <meta http-equiv="content-language" content="<?php print $language ?>" />
  <?php print $meta ?>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $path ?>ie.css" type="text/css">
  <![endif]-->
  <!--[if lte IE 6]>
    <link rel="stylesheet" href="<?php print $path ?>ie6.css" type="text/css">
  <![endif]-->
</head>

<body class="layout-<?php print $layout ?>">
  <div id="page">

    <div id="header">
      <?php if ($header || $search_box): ?>
        <div id="header-right">
          <?php print $header ?>
          <?php print $search_box ?>
        </div>
      <?php endif; ?>

      <a id="logo" href="<?php print url(); ?>"><span id="site-name"><?php print $site_name ?></span></a>
      <span id="slogan"><?php print $site_slogan ?></span>
    </div>

    <?php if (isset($primary_links)): ?>
      <div id="navigation">
          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php if (isset($secondary_links)) : ?>
          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
        <?php endif; ?>
      </div>
    <?php endif; ?>

    <?php print $breadcrumb ?>

    <?php print $left ?>

    <div id="centre">
      <?php print $messages ?>

      <?php if ($tabs): ?>
        <div class="tabs"><?php print $tabs ?></div>
      <?php endif; ?>

      <?php if ($title): ?>
        <h1 class="page-title"><?php print $title ?></h1>
      <?php endif; ?>

      <?php print $help ?>
      <?php print $content ?>
      <?php print $feed_icons ?>

    </div><!--// centre -->

    <?php print $right; ?>

    <?php if ($footer_message): ?>
      <div id="footer"><?php print $footer_message ?></div>
    <?php endif; ?>

    <?php print $closure ?>
  </div><!--// page -->
</body>
</html>

==> clean-5.x-1.5.tar.gz: clean/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.1.2.6 2008/11/13 15:28:22 psynaptic Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language ?>" lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <meta http-equiv="content-language" content="<?php print $language ?>" />
  <?php print $meta ?>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $path ?>ie.css" type="text/css">
  <![endif]-->
  <!--[if lte IE 6]>
    <link rel="stylesheet" href="<?php print $path ?>ie6.css" type="text/css">
  <![endif]-->
</head>

<body class="layout-<?php print $layout ?>">
  <div id="page">

    <div id="header">
      <?php if ($header || $search_box): ?>
        <div id="header-right">
          <?php print $header ?>
          <?php print $search_box ?>
        </div>
      <?php endif ?>

      <?php if ($logo): ?>
        <a id="logo" href="<?php print $base_path ?>">
          <?php print theme('image', $logo) ?>
        </a>
      <?php endif ?>
      <?php if ($site_name): ?>
        <a id="site-name" href="<?php print $base_path ?>">
          <?php print $site_name ?>
        </a>
      <?php endif ?>
      <?php if ($site_slogan): ?>
        <span id="slogan"><?php print $site_slogan ?></span>
      <?php endif ?>
    </div>

    <?php if (isset($primary_links)): ?>
      <div id="navigation">
        <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php if (isset($secondary_links)) : ?>
          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
        <?php endif ?>
      </div>
    <?php endif ?>

    <?php print $breadcrumb ?>

    <?php if ($sidebar_left): ?>
      <div class="left sidebar">
        <?php print $sidebar_left ?>
      </div>
    <?php endif ?>

    <div id="centre">
      <?php print $messages ?>

      <?php if ($tabs): ?>
        <div class="tabs"><?php print $tabs ?></div>
      <?php endif ?>

      <?php if ($title): ?>
        <h1 class="page-title"><?php print $title ?></h1>
      <?php endif ?>

      <?php print $help ?>
      <?php print $content ?>
      <?php print $feed_icons ?>

    </div><!--// centre -->

    <?php if ($sidebar_right): ?>
      <div class="right sidebar">
        <?php print $sidebar_right ?>
      </div>
    <?php endif ?>

    <?php if ($footer_message): ?>
      <div id="footer">
        <?php print $footer_message ?>
      </div>
    <?php endif ?>

  </div><!--// page -->

  <?php print $closure ?>
</body>
</html>
